@@ -1,8 +1,8 @@
 #!/usr/bin/env python
 # -*- coding: UTF-8 -*-
 
-# Copyright 2006-2007 (C) Raster Software Vigo (Sergio Costas)
-# Copyright 2006-2007 (C) Peter Gill - win32 parts
+# Copyright 2006-2009 (C) Raster Software Vigo (Sergio Costas)
+# Copyright 2006-2009 (C) Peter Gill - win32 parts
 
 # This file is part of DeVeDe
 #
@@ -22,10 +22,10 @@
 import pygtk # for testing GTK version number
 pygtk.require ('2.0')
 import gtk
-import gtk.glade
 import pickle
 import os
 
+import devede_other
 import devede_dialogs
 import devede_newfiles
 
@@ -52,8 +52,8 @@ class load_save_config:
 				return
 
 		if file_name==None:
-			tree=gtk.glade.XML(self.gladefile,"wloadconfig",domain="devede")
-			window = tree.get_widget("wloadconfig")
+			tree=devede_other.create_tree(self,"wloadconfig",self.gladefile,False)
+			window = tree.get_object("wloadconfig")
 			
 			filter = gtk.FileFilter()
 			filter.add_pattern("*.devede")
@@ -112,7 +112,7 @@ class load_save_config:
 					not_found.append(str(element2["path"]))
 					continue
 				
-				if False==element2.has_key("copy_sound"):
+				if False==element2.has_key("copy_audio"):
 					element2["copy_audio"]=False # for backward compatibility
 				if False==element2.has_key("sound51"):
 					element2["sound51"]=False # for backward compatibility
@@ -124,6 +124,20 @@ class load_save_config:
 					element2["hmirror"]=False
 				if False==element2.has_key("gop12"):
 					element2["gop12"]=True # for backward compatibility
+				if False==element2.has_key("isvob"):
+					element2["isvob"]=False # for backward compatibility
+				if False==element2.has_key("swap_fields"):
+					element2["swap_fields"]=False # for backward compatibility
+				if False==element2.has_key("twopass"):
+					element2["twopass"]=False # for backward compatibility
+				if False==element2.has_key("turbo1stpass"):
+					element2["turbo1stpass"]=False # for backward compatibility
+				if False==element2.has_key("subfont_size"):
+					element2["subfont_size"]=28 # subtitle font size
+				if False==element2.has_key("volume"):
+					element2["volume"]=100 # default volume (in percentage)
+				if False==element2.has_key("force_subs"):
+					element2["force_subs"]=False # by default, subtitles aren't forced
 				
 				if False==element2.has_key("audio_stream"):
 					fileprop=devede_newfiles.newfile("","")
@@ -144,6 +158,7 @@ class load_save_config:
 						del element2["subtitles"]
 						del element2["sub_codepage"]
 						del element2["subtitles_up"]
+						element2["sub_list"].append(tmp)
 				
 	
 		if len(not_found)!=0:
@@ -159,13 +174,15 @@ class load_save_config:
 		except:
 			w = devede_dialogs.show_error(self.gladefile,_("Can't find the menu background. I'll open the disc structure anyway with the default menu background, so don't forget to fix it before creating the disc."))
 			w = None
-			global_vars2["menu_bg"]=self.global_vars["path"]+"background.png"
+			global_vars2["menu_bg"]=os.path.join(self.global_vars["path"],"backgrounds","default_bg.png")
 			
 		use_default_sound=False
-		
+	
 		if False==global_vars2.has_key("menu_sound"):
 			use_default_sound=True
 		else:
+			if (global_vars2["menu_sound"][-11:]=="silence.mp3"):
+				global_vars2["menu_sound"]=os.path.join(self.global_vars["path"],"silence.ogg")
 			try:
 				os.stat(global_vars2["menu_sound"])
 			except:
@@ -173,6 +190,12 @@ class load_save_config:
 				w = devede_dialogs.show_error(self.gladefile,_("Can't find the menu soundtrack file. I'll open the disc structure anyway with a silent soundtrack, so don't forget to fix it before creating the disc."))
 				w = None
 		
+		if (use_default_sound):
+			global_vars2["menu_sound"]=os.path.join(self.global_vars["path"],"silence.ogg")
+
+		if False==global_vars2.has_key("with_menu"):
+			global_vars2["with_menu"]=True
+		
 		if False==global_vars2.has_key("menu_halignment"):
 			global_vars2["menu_halignment"]=2 # center
 			
@@ -181,14 +204,11 @@ class load_save_config:
 			
 		if False==global_vars2.has_key("menu_title_shadow"):
 			global_vars2["menu_title_shadow"]=[0,0,0,0]
-			
-		if use_default_sound:
-			global_vars2["menu_sound"]=os.path.join(self.global_vars["path"],"silence.mp3")
 
 		test=devede_newfiles.file_get_params()
 		check,channels=test.read_file_values(global_vars2["menu_sound"],True)
 		if (check!=False) or (channels!=1):
-			global_vars2["menu_sound"]=os.path.join(self.global_vars["path"],"silence.mp3")
+			global_vars2["menu_sound"]=os.path.join(self.global_vars["path"],"silence.ogg")
 			w = devede_dialogs.show_error(self.gladefile,_("The menu soundtrack seems damaged. Using the default silent soundtrack."))
 			w = None
 			check,channels=test.read_file_values(global_vars2["menu_sound"],True)
@@ -216,9 +236,9 @@ class load_save_config:
 			self.global_vars["menu_title_fontname"]="Sans 14"
 
 		if global_vars2.has_key("erase_files")==False:
-			w=self.tree.get_widget("create_iso")
+			w=self.tree.get_object("create_iso")
 			w.set_active(True)
-			w=self.tree.get_widget("erase_files")
+			w=self.tree.get_object("erase_files")
 			w.set_active(True)
 
 		self.global_vars["struct_name"]=file_name # update the path
@@ -233,13 +253,13 @@ class load_save_config:
 			(from a previous save), it will overwrite the old file """
 	
 		if mode or (self.global_vars["struct_name"]==""):
-			tree=gtk.glade.XML(self.gladefile,"wsaveconfig",domain="devede")
-			saveconfig=tree.get_widget("wsaveconfig")
+			tree=devede_other.create_tree(self,"wsaveconfig",self.gladefile,False)
+			saveconfig=tree.get_object("wsaveconfig")
 			
 			filter=gtk.FileFilter()
 			filter.add_pattern("*.devede")
 			filter.set_name(".devede")
-			saveconfig=tree.get_widget("wsaveconfig")
+			saveconfig=tree.get_object("wsaveconfig")
 			saveconfig.add_filter(filter)
 			saveconfig.set_do_overwrite_confirmation(True)
 
@@ -273,6 +293,7 @@ class load_save_config:
 			vars["disctocreate"]=self.global_vars["disctocreate"]
 			vars["titlecounter"]=self.global_vars["titlecounter"]
 			vars["do_menu"]=self.global_vars["do_menu"]
+			vars["with_menu"]=self.global_vars["with_menu"]
 			vars["menu_widescreen"]=self.global_vars["menu_widescreen"]
 			vars["PAL"]=self.global_vars["PAL"]
 			vars["menu_bg"]=self.global_vars["menu_bg"]
@@ -290,11 +311,11 @@ class load_save_config:
 			vars["menu_title_text"]=self.global_vars["menu_title_text"]
 			vars["menu_title_fontname"]=self.global_vars["menu_title_fontname"]
 			
-			w=self.tree.get_widget("erase_files")
+			w=self.tree.get_object("erase_files")
 			vars["erase_files"]=w.get_active()
-			if self.tree.get_widget("create_iso").get_active():
+			if self.tree.get_object("create_iso").get_active():
 				vars["action_todo"]=2
-			elif self.tree.get_widget("create_dvd").get_active():
+			elif self.tree.get_object("create_dvd").get_active():
 				vars["action_todo"]=1
 			else:
 				vars["action_todo"]=0
